@@ -8,7 +8,7 @@ NULL
 
 ## quiets concerns of R CMD check re: the .'s that appear in pipelines
 if (getRversion() >= "2.15.1") {
-  utils::globalVariables(c(
+  globalVariables(c(
     ".", "df", "chi", "x", "y", "z", "x1", "x2"
   ))
 }
